mpservice
=========

The package ``mpservice`` provides a few groups of facilities. The first group helps orchestrating an operation 
with multiple stages/components in threads and processes, such as a machine learning model;
the second group concerns stream processing, optionally involving threads or processes for concurrency;
the third group provides customization and enhancements to the standard packages ``multiprocessing`` and ``threading``.
The central theme of ``mpservice`` is concurrency by threads or processes.

Read the `documentation <https://mpservice.readthedocs.io/en/latest/>`_.

To install, do

::
    
    python3 -m pip install mpservice


Status
------

Production ready. Under active development.



Licence
-------

In addition to what the LICENSE file states, permission is **NOT** granted
for any content of this repository to be used in training, or "development" in general,
of "coding assistance" or "code generation" models.
